@@ -67,6 +67,10 @@ def bump(
     except AppOperationAborted:
         print(success_negative("Aborted."))
         return
+
+    if push:
+        run(f"cd {APPS_PATH}; git pull")
+
     for app in apps:
         app_name = app.name
         prev_image_tag = app.image_tag
@@ -116,7 +120,15 @@ def bump(
 
 @task
 def command(
-    ctx, filter, command, exclude="", cleanup=True, sequential=True, interactive=True, fargate=False
+    ctx,
+    filter,
+    command,
+    exclude="",
+    cleanup=True,
+    sequential=True,
+    interactive=True,
+    cpu=0,
+    memory=0,
 ):
     """Run command on selected app(s).
 
@@ -143,19 +155,21 @@ def command(
             # For each app, just run the coroutine and print the output
             print(
                 asyncio.run(
-                    run_job(app, command, cleanup=cleanup, sequential=True, fargate=fargate)
+                    run_job(app, command, cleanup=cleanup, sequential=True, cpu=cpu, memory=memory)
                 )
             )
     else:
         # Build list of coroutines, and execute them all at once
         jobs = [
             (
-                run_job(app, command, cleanup=cleanup, sequential=sequential, fargate=fargate),
+                run_job(
+                    app, command, cleanup=cleanup, sequential=sequential, cpu=cpu, memory=memory
+                ),
                 app.name,
             )
             for app in apps
         ]
-        asyncio.run(run_tasks_async_with_progress(jobs, max_concurrency=100 if fargate else 10))
+        asyncio.run(run_tasks_async_with_progress(jobs, max_concurrency=10))
 
     print(success("Done!"))
 
